Stan Math Library: stan/math/prim/mat/fun/divide.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

divide.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_DIVIDE_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_DIVIDE_HPP
3
4 #include <boost/type_traits/is_arithmetic.hpp>
5 #include <boost/utility/enable_if.hpp>
6 #include <stan/math/prim/mat/fun/Eigen.hpp>
7
8 namespace stan {
9 namespace math {
10
19 template <int R, int C, typename T>
20 inline
21 typename boost::enable_if_c<boost::is_arithmetic<T>::value,
22 Eigen::Matrix<double, R, C> >::type
23 divide(const Eigen::Matrix<double, R, C>& m,
24 T c) {
25 return m / c;
26 }
27
28 }
29 }
30 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::divide
Eigen::Matrix< fvar< T >, R, C > divide(const Eigen::Matrix< fvar< T >, R, C > &v, const fvar< T > &c)
Definition: divide.hpp:16
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.